==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/network/kotlin/inputs/LoadBalancerSkuArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.network.kotlin.inputs

import com.pulumi.azurenative.network.inputs.LoadBalancerSkuArgs.builder
import com.pulumi.azurenative.network.kotlin.enums.LoadBalancerSkuName
import com.pulumi.azurenative.network.kotlin.enums.LoadBalancerSkuTier
import com.pulumi.core.Either
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * SKU of a load balancer.
 * @property name Name of a load balancer SKU.
 * @property tier Tier of a load balancer SKU.
 */
public data class LoadBalancerSkuArgs(
    public val name: Output<Either<String, LoadBalancerSkuName>>? = null,
    public val tier: Output<Either<String, LoadBalancerSkuTier>>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.network.inputs.LoadBalancerSkuArgs> {
    override fun toJava(): com.pulumi.azurenative.network.inputs.LoadBalancerSkuArgs =
        com.pulumi.azurenative.network.inputs.LoadBalancerSkuArgs.builder()
            .name(
                name?.applyValue({ args0 ->
                    args0.transform({ args0 -> args0 }, { args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            )
            .tier(
                tier?.applyValue({ args0 ->
                    args0.transform({ args0 -> args0 }, { args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            ).build()
}

/**
 * Builder for [LoadBalancerSkuArgs].
 */
@PulumiTagMarker
public class LoadBalancerSkuArgsBuilder internal constructor() {
    private var name: Output<Either<String, LoadBalancerSkuName>>? = null

    private var tier: Output<Either<String, LoadBalancerSkuTier>>? = null

    /**
     * @param value Name of a load balancer SKU.
     */
    @JvmName("ywygdvfyupytgoss")
    public suspend fun name(`value`: Output<Either<String, LoadBalancerSkuName>>) {
        this.name = value
    }

    /**
     * @param value Tier of a load balancer SKU.
     */
    @JvmName("ccqgjdpqmjskpwnk")
    public suspend fun tier(`value`: Output<Either<String, LoadBalancerSkuTier>>) {
        this.tier = value
    }

    /**
     * @param value Name of a load balancer SKU.
     */
    @JvmName("kneobdlnwerjcrsx")
    public suspend fun name(`value`: Either<String, LoadBalancerSkuName>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.name = mapped
    }

    /**
     * @param value Name of a load balancer SKU.
     */
    @JvmName("demutfrxfddandpo")
    public fun name(`value`: String) {
        val toBeMapped = Either.ofLeft<String, LoadBalancerSkuName>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.name = mapped
    }

    /**
     * @param value Name of a load balancer SKU.
     */
    @JvmName("pojkoamclrbxhupg")
    public fun name(`value`: LoadBalancerSkuName) {
        val toBeMapped = Either.ofRight<String, LoadBalancerSkuName>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.name = mapped
    }

    /**
     * @param value Tier of a load balancer SKU.
     */
    @JvmName("fmfikqsqrdjfulss")
    public suspend fun tier(`value`: Either<String, LoadBalancerSkuTier>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.tier = mapped
    }

    /**
     * @param value Tier of a load balancer SKU.
     */
    @JvmName("vhecvjwacnvukiny")
    public fun tier(`value`: String) {
        val toBeMapped = Either.ofLeft<String, LoadBalancerSkuTier>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.tier = mapped
    }

    /**
     * @param value Tier of a load balancer SKU.
     */
    @JvmName("mrhsxhlxpabxiosm")
    public fun tier(`value`: LoadBalancerSkuTier) {
        val toBeMapped = Either.ofRight<String, LoadBalancerSkuTier>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.tier = mapped
    }

    internal fun build(): LoadBalancerSkuArgs = LoadBalancerSkuArgs(
        name = name,
        tier = tier,
    )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/network/kotlin/inputs/LoadBalancerSkuArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.network.kotlin.inputs

import com.pulumi.azurenative.network.inputs.LoadBalancerSkuArgs.builder
import com.pulumi.azurenative.network.kotlin.enums.LoadBalancerSkuName
import com.pulumi.azurenative.network.kotlin.enums.LoadBalancerSkuTier
import com.pulumi.core.Either
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * SKU of a load balancer.
 * @property name Name of a load balancer SKU.
 * @property tier Tier of a load balancer SKU.
 */
public data class LoadBalancerSkuArgs(
    public val name: Output<Either<String, LoadBalancerSkuName>>? = null,
    public val tier: Output<Either<String, LoadBalancerSkuTier>>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.network.inputs.LoadBalancerSkuArgs> {
    override fun toJava(): com.pulumi.azurenative.network.inputs.LoadBalancerSkuArgs =
        com.pulumi.azurenative.network.inputs.LoadBalancerSkuArgs.builder()
            .name(
                name?.applyValue({ args0 ->
                    args0.transform({ args0 -> args0 }, { args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            )
            .tier(
                tier?.applyValue({ args0 ->
                    args0.transform({ args0 -> args0 }, { args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            ).build()
}

/**
 * Builder for [LoadBalancerSkuArgs].
 */
@PulumiTagMarker
public class LoadBalancerSkuArgsBuilder internal constructor() {
    private var name: Output<Either<String, LoadBalancerSkuName>>? = null

    private var tier: Output<Either<String, LoadBalancerSkuTier>>? = null

    /**
     * @param value Name of a load balancer SKU.
     */
    @JvmName("micqeauvumhoanfr")
    public suspend fun name(`value`: Output<Either<String, LoadBalancerSkuName>>) {
        this.name = value
    }

    /**
     * @param value Tier of a load balancer SKU.
     */
    @JvmName("ulshjgggkjtafycl")
    public suspend fun tier(`value`: Output<Either<String, LoadBalancerSkuTier>>) {
        this.tier = value
    }

    /**
     * @param value Name of a load balancer SKU.
     */
    @JvmName("etyfrsxtqoxpuggw")
    public suspend fun name(`value`: Either<String, LoadBalancerSkuName>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.name = mapped
    }

    /**
     * @param value Name of a load balancer SKU.
     */
    @JvmName("hxwijagrrkxyowlo")
    public fun name(`value`: String) {
        val toBeMapped = Either.ofLeft<String, LoadBalancerSkuName>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.name = mapped
    }

    /**
     * @param value Name of a load balancer SKU.
     */
    @JvmName("gvkswdjiakssicoa")
    public fun name(`value`: LoadBalancerSkuName) {
        val toBeMapped = Either.ofRight<String, LoadBalancerSkuName>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.name = mapped
    }

    /**
     * @param value Tier of a load balancer SKU.
     */
    @JvmName("efxdlvyswltvsdig")
    public suspend fun tier(`value`: Either<String, LoadBalancerSkuTier>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.tier = mapped
    }

    /**
     * @param value Tier of a load balancer SKU.
     */
    @JvmName("myarpobxjantvjny")
    public fun tier(`value`: String) {
        val toBeMapped = Either.ofLeft<String, LoadBalancerSkuTier>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.tier = mapped
    }

    /**
     * @param value Tier of a load balancer SKU.
     */
    @JvmName("omppaccdbrrmbpef")
    public fun tier(`value`: LoadBalancerSkuTier) {
        val toBeMapped = Either.ofRight<String, LoadBalancerSkuTier>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.tier = mapped
    }

    internal fun build(): LoadBalancerSkuArgs = LoadBalancerSkuArgs(
        name = name,
        tier = tier,
    )
}
